#!/bin/python

from Particle_Board_REPL.main import init


def main():
    init()


if __name__ == "__main__":
    main()
